==> provider-upload-local-custom-4.19.1.tgz: package/src/index.js <==
"use strict";
const stream = require("stream");
const fs = require("fs");
const path = require("path");
const fse = require("fs-extra");
const utils = require("@strapi/utils");
const logging = require("@strapi/logger");
const logger = logging.createLogger();
const _interopDefault = (e) => e && e.__esModule ? e : { default: e };
function _interopNamespace(e) {
  if (e && e.__esModule)
    return e;
  const n = Object.create(null, { [Symbol.toStringTag]: { value: "Module" } });
  if (e) {
    for (const k in e) {
      if (k !== "default") {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}
const fs__default = /* @__PURE__ */ _interopDefault(fs);
const path__default = /* @__PURE__ */ _interopDefault(path);
const fse__default = /* @__PURE__ */ _interopDefault(fse);
const utils__namespace = /* @__PURE__ */ _interopNamespace(utils);
const { PayloadTooLargeError } = utils__namespace.errors;
const { kbytesToBytes, bytesToHumanReadable } = utils__namespace.file;
const PUBLIC_FOLDER_NAME = "public";
const UPLOADS_FOLDER_NAME = "uploads";
const index = {
  init(config) {
    const providerOptionsSizeLimit = config.sizeLimit;
    console.log("strapi-provider-upload-custom::options ");
    return {
      checkFileSize(file, options) {
        const { sizeLimit } = options ?? {};
        if (providerOptionsSizeLimit) {
          if (kbytesToBytes(file.size) > providerOptionsSizeLimit)
            throw new PayloadTooLargeError(
              `${file.name} exceeds size limit of ${bytesToHumanReadable(
                providerOptionsSizeLimit
              )}.`
            );
        } else if (sizeLimit) {
          if (kbytesToBytes(file.size) > sizeLimit)
            throw new PayloadTooLargeError(
              `${file.name} exceeds size limit of ${bytesToHumanReadable(sizeLimit)}.`
            );
        }
      },
      uploadStream(file) {
        let uploadPath = getUploadPath(file.type, file.ownerId);
        let uploadUrl = getUploadUrl(file.type, file.ownerId);
        if (!file.stream) {
          return Promise.reject(new Error("Missing file stream"));
        }
        const { stream: stream$1 } = file;
        return new Promise((resolve, reject) => {
          stream.pipeline(
            stream$1,
            fs__default.default.createWriteStream(path__default.default.join(uploadPath, `${file.hash}${file.ext}`)),
            (err) => {
              if (err) {
                return reject(err);
              }
              file.url = `/${uploadUrl}/${file.hash}${file.ext}`;
              resolve();
            }
          );
        });
      },
      upload(file) {
        let uploadPath = getUploadPath(file.type, file.ownerId);
        let uploadUrl = getUploadUrl(file.type, file.ownerId);
        if (!file.buffer) {
          return Promise.reject(new Error("Missing file buffer"));
        }
        const { buffer } = file;
        return new Promise((resolve, reject) => {
          fs__default.default.writeFile(path__default.default.join(uploadPath, `${file.hash}${file.ext}`), buffer, (err) => {
            if (err) {
              return reject(err);
            }
            file.url = `/${uploadUrl}/${file.hash}${file.ext}`;
            resolve();
          });
        });
      },
      delete(file) {
        let deletePath = getDeletePath(file);
        return new Promise((resolve, reject) => {
          if (!fs__default.default.existsSync(deletePath)) {
            resolve("File doesn't exist");
            return;
          }
          fs__default.default.unlink(deletePath, (err) => {
            if (err) {
              return reject(err);
            }
            resolve();
          });
        });
      }
    };
  }
};

const getDeletePath = (file) => {
  let deletePath;
  deletePath = path__default.default.resolve(strapi.dirs.static.public, "..");
  deletePath = deletePath + file.url;

  console.log("strapi-provider-upload-custom::getDeletePath ", deletePath);

  return deletePath;
};

const getUploadUrl = (type, ownerId) => {
  let uploadUrl;
  const date = new Date();
  const currentYear = date.getFullYear().toString();

  if (type === "private") {
    uploadUrl =
      type + "/" + UPLOADS_FOLDER_NAME + "/" + ownerId + "/" + currentYear;
  } else if (type === "public") {
    uploadUrl = PUBLIC_FOLDER_NAME + "/" + UPLOADS_FOLDER_NAME;
  }

  return uploadUrl;
};
const getUploadPath = (type, ownerId) => {
  console.log("ownerId ", ownerId);
  console.log("type ", type);
  let uploadPath;
  const currentYear = new Date().getFullYear().toString();

  if (type === "private") {
    uploadPath = path__default.default.resolve(
      strapi.dirs.static.public,
      "../private",
      UPLOADS_FOLDER_NAME,
      ownerId,
      currentYear
    );
  } else if (type === "public") {
    uploadPath = path__default.default.resolve(
      strapi.dirs.static.public,
      UPLOADS_FOLDER_NAME
    );
  } else {
    logger.warn("Provider: No matching type (private/public) found");
  }
  console.log("strapi-provider-upload-custom::getUploadPath ", uploadPath);
  if (!checkIfPathExists(uploadPath)) {
    fse__default.default.mkdirpSync(uploadPath);
  }

  return uploadPath;
};

const checkIfPathExists = (uploadPath) => {
  if (!fse__default.default.pathExistsSync(uploadPath)) {
    return false;
  } else {
    return true;
  }
};

module.exports = index;

==> provider-upload-local-custom-4.19.2.tgz: package/src/index.js <==
"use strict";
const stream = require("stream");
const fs = require("fs");
const path = require("path");
const fse = require("fs-extra");
const utils = require("@strapi/utils");
const logging = require("@strapi/logger");
const logger = logging.createLogger();
const _interopDefault = (e) => e && e.__esModule ? e : { default: e };
function _interopNamespace(e) {
  if (e && e.__esModule)
    return e;
  const n = Object.create(null, { [Symbol.toStringTag]: { value: "Module" } });
  if (e) {
    for (const k in e) {
      if (k !== "default") {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}
const fs__default = /* @__PURE__ */ _interopDefault(fs);
const path__default = /* @__PURE__ */ _interopDefault(path);
const fse__default = /* @__PURE__ */ _interopDefault(fse);
const utils__namespace = /* @__PURE__ */ _interopNamespace(utils);
const { PayloadTooLargeError } = utils__namespace.errors;
const { kbytesToBytes, bytesToHumanReadable } = utils__namespace.file;
const PUBLIC_FOLDER_NAME = "public";
const UPLOADS_FOLDER_NAME = "uploads";
const index = {
  init(config) {
    const providerOptionsSizeLimit = config.sizeLimit;
    console.log("strapi-provider-upload-custom::options 4.19.1");
    return {
      checkFileSize(file, options) {
        const { sizeLimit } = options ?? {};
        if (providerOptionsSizeLimit) {
          if (kbytesToBytes(file.size) > providerOptionsSizeLimit)
            throw new PayloadTooLargeError(
              `${file.name} exceeds size limit of ${bytesToHumanReadable(
                providerOptionsSizeLimit
              )}.`
            );
        } else if (sizeLimit) {
          if (kbytesToBytes(file.size) > sizeLimit)
            throw new PayloadTooLargeError(
              `${file.name} exceeds size limit of ${bytesToHumanReadable(sizeLimit)}.`
            );
        }
      },
      uploadStream(file) {
        let uploadPath = getUploadPath(file.type, file.ownerId);
        let uploadUrl = getUploadUrl(file.type, file.ownerId);
        if (!file.stream) {
          return Promise.reject(new Error("Missing file stream"));
        }
        const { stream: stream$1 } = file;
        return new Promise((resolve, reject) => {
          stream.pipeline(
            stream$1,
            fs__default.default.createWriteStream(path__default.default.join(uploadPath, `${file.hash}${file.ext}`)),
            (err) => {
              if (err) {
                return reject(err);
              }
              file.url = `/${uploadUrl}/${file.hash}${file.ext}`;
              resolve();
            }
          );
        });
      },
      upload(file) {
        let uploadPath = getUploadPath(file.type, file.ownerId);
        let uploadUrl = getUploadUrl(file.type, file.ownerId);
        if (!file.buffer) {
          return Promise.reject(new Error("Missing file buffer"));
        }
        const { buffer } = file;
        return new Promise((resolve, reject) => {
          fs__default.default.writeFile(path__default.default.join(uploadPath, `${file.hash}${file.ext}`), buffer, (err) => {
            if (err) {
              return reject(err);
            }
            file.url = `/${uploadUrl}/${file.hash}${file.ext}`;
            resolve();
          });
        });
      },
      delete(file) {
        let deletePath = getDeletePath(file);
        return new Promise((resolve, reject) => {
          if (!fs__default.default.existsSync(deletePath)) {
            resolve("File doesn't exist");
            return;
          }
          fs__default.default.unlink(deletePath, (err) => {
            if (err) {
              return reject(err);
            }
            resolve();
          });
        });
      }
    };
  }
};

const getDeletePath = (file) => {
  let deletePath;
  deletePath = path__default.default.resolve(strapi.dirs.static.public, "..");
  deletePath = deletePath + file.url;

  console.log("strapi-provider-upload-custom::getDeletePath ", deletePath);

  return deletePath;
};

const getUploadUrl = (type, ownerId) => {
  let uploadUrl;
  const date = new Date();
  const currentYear = date.getFullYear().toString();

  if (type === "private") {
    uploadUrl =
      type + "/" + UPLOADS_FOLDER_NAME + "/" + ownerId + "/" + currentYear;
  } else if (type === "public") {
    uploadUrl = PUBLIC_FOLDER_NAME + "/" + UPLOADS_FOLDER_NAME;
  }

  return uploadUrl;
};
const getUploadPath = (type, ownerId) => {
  console.log("ownerId ", ownerId);
  console.log("type ", type);
  let uploadPath;
  const currentYear = new Date().getFullYear().toString();

  if (type === "private") {
    uploadPath = path__default.default.resolve(
      strapi.dirs.static.public,
      "../private",
      UPLOADS_FOLDER_NAME,
      ownerId,
      currentYear
    );
  } else if (type === "public") {
    uploadPath = path__default.default.resolve(
      strapi.dirs.static.public,
      UPLOADS_FOLDER_NAME
    );
  } else {
    logger.warn("Provider: No matching type (private/public) found");
  }
  console.log("strapi-provider-upload-custom::getUploadPath ", uploadPath);
  if (!checkIfPathExists(uploadPath)) {
    fse__default.default.mkdirpSync(uploadPath);
  }

  return uploadPath;
};

const checkIfPathExists = (uploadPath) => {
  if (!fse__default.default.pathExistsSync(uploadPath)) {
    return false;
  } else {
    return true;
  }
};

module.exports = index;
